@@ -159,6 +159,7 @@ from netapp_ontap.models.performance_metric_io_type_rwt import PerformanceMetric
 from netapp_ontap.models.oracle_on_san_new_igroups import OracleOnSanNewIgroups
 from netapp_ontap.models.volume_clone import VolumeClone
 from netapp_ontap.models.sql_on_smb import SqlOnSmb
+from netapp_ontap.models.security_association_ipsec import SecurityAssociationIpsec
 from netapp_ontap.models.aggregate_block_storage_mirror import AggregateBlockStorageMirror
 from netapp_ontap.models.audit_schedule import AuditSchedule
 from netapp_ontap.models.account_application import AccountApplication
@@ -180,6 +181,7 @@ from netapp_ontap.models.quota_rule_files import QuotaRuleFiles
 from netapp_ontap.models.chassis_frus import ChassisFrus
 from netapp_ontap.models.quota_rule_group import QuotaRuleGroup
 from netapp_ontap.models.usm import Usm
+from netapp_ontap.models.ipsec_endpoint import IpsecEndpoint
 from netapp_ontap.models.lun_map_lun import LunMapLun
 from netapp_ontap.models.application_san_access_backing_storage import ApplicationSanAccessBackingStorage
 from netapp_ontap.models.s3_service_user_post import S3ServiceUserPost
@@ -325,6 +327,7 @@ from netapp_ontap.models.aggregate_block_storage_hybrid_cache import AggregateBl
 from netapp_ontap.models.rotation import Rotation
 from netapp_ontap.models.sql_on_san_db_storage_service import SqlOnSanDbStorageService
 from netapp_ontap.models.volume_autosize import VolumeAutosize
+from netapp_ontap.models.security_association_ipsec_outbound import SecurityAssociationIpsecOutbound
 from netapp_ontap.models.application_nfs_properties_export_policy import ApplicationNfsPropertiesExportPolicy
 from netapp_ontap.models.ndmp_mover import NdmpMover
 from netapp_ontap.models.nas_application_components import NasApplicationComponents
@@ -355,6 +358,7 @@ from netapp_ontap.models.software_errors import SoftwareErrors
 from netapp_ontap.models.application_nfs_properties import ApplicationNfsProperties
 from netapp_ontap.models.license_keys import LicenseKeys
 from netapp_ontap.models.cluster_peer_remote import ClusterPeerRemote
+from netapp_ontap.models.security_association_ipsec_inbound import SecurityAssociationIpsecInbound
 from netapp_ontap.models.application_rpo import ApplicationRpo
 from netapp_ontap.models.maxdata_on_san_application_components_metadata import MaxdataOnSanApplicationComponentsMetadata
 from netapp_ontap.models.lun_movement_progress import LunMovementProgress
@@ -378,6 +382,7 @@ from netapp_ontap.models.cluster_peer_local_network import ClusterPeerLocalNetwo
 from netapp_ontap.models.application_svm import ApplicationSvm
 from netapp_ontap.models.vdi_on_nas_desktops import VdiOnNasDesktops
 from netapp_ontap.models.performance_svm import PerformanceSvm
+from netapp_ontap.models.security_association_ike import SecurityAssociationIke
 from netapp_ontap.models.bgp_peer_group_peer import BgpPeerGroupPeer
 from netapp_ontap.models.cluster_peer_setup import ClusterPeerSetup
 from netapp_ontap.models.vdi_on_nas_desktops_storage_service import VdiOnNasDesktopsStorageService
@@ -600,6 +605,7 @@ __all__ = [
     "OracleOnSanNewIgroups",
     "VolumeClone",
     "SqlOnSmb",
+    "SecurityAssociationIpsec",
     "AggregateBlockStorageMirror",
     "AuditSchedule",
     "AccountApplication",
@@ -621,6 +627,7 @@ __all__ = [
     "ChassisFrus",
     "QuotaRuleGroup",
     "Usm",
+    "IpsecEndpoint",
     "LunMapLun",
     "ApplicationSanAccessBackingStorage",
     "S3ServiceUserPost",
@@ -766,6 +773,7 @@ __all__ = [
     "Rotation",
     "SqlOnSanDbStorageService",
     "VolumeAutosize",
+    "SecurityAssociationIpsecOutbound",
     "ApplicationNfsPropertiesExportPolicy",
     "NdmpMover",
     "NasApplicationComponents",
@@ -796,6 +804,7 @@ __all__ = [
     "ApplicationNfsProperties",
     "LicenseKeys",
     "ClusterPeerRemote",
+    "SecurityAssociationIpsecInbound",
     "ApplicationRpo",
     "MaxdataOnSanApplicationComponentsMetadata",
     "LunMovementProgress",
@@ -819,6 +828,7 @@ __all__ = [
     "ApplicationSvm",
     "VdiOnNasDesktops",
     "PerformanceSvm",
+    "SecurityAssociationIke",
     "BgpPeerGroupPeer",
     "ClusterPeerSetup",
     "VdiOnNasDesktopsStorageService",
