@@ -28,9 +28,11 @@ from typing import (  # pylint: disable=unused-import
 import urllib.parse
 
 import marshmallow  # type: ignore
+from marshmallow import (  # type: ignore
+    missing,
+)
 import requests
 
-import netapp_ontap
 from netapp_ontap import config, utils
 from netapp_ontap.error import NetAppRestError
 from netapp_ontap.host_connection import HostConnection
@@ -142,7 +144,6 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         self._prevent_recurse = False
         self._connection = HostConnection.get_host_context()
         self._last_response = None  # type: Optional[NetAppResponse]
-        self._request_session = None  # type: Optional[requests.Session]
         self.parent_keys = args
         if getattr(self.__class__, "_schema_instance", None) is None:
             self.__class__._schema_instance = self._schema()  # pylint: disable=protected-access
@@ -172,7 +173,10 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         https://docs.python.org/3/library/functions.html#dir
         """
 
-        return list(super().__dir__()) + self._schema_fields
+        field_list = list(super().__dir__())
+        if self._schema_fields:
+            field_list += self._schema_fields
+        return field_list
 
     def __getattribute__(self, name):
         """Here we will examine the name being retrieved. If it is a child resource
@@ -345,51 +349,6 @@ class Resource:  # pylint: disable=too-many-instance-attributes
             return "%s/%s" % (self._location, "/".join(key_vals))
         return self._location
 
-    @property
-    def _session(self) -> requests.Session:
-        """A `requests.Session` object which is used for all API calls.
-
-        This session is reused for each API call made with this resource. Multiple
-        requests may therefore be sent through the same TCP connection assuming
-        the host supports keep-alive.
-
-        Note: If a new `netapp_ontap.host_connection.HostConnection` object is set
-        on `netapp_ontap.config.CONNECTION`, this does not update the connection
-        or session objects on already existing resources. To update a connection
-        on a long lived resource object, call `netapp_ontap.resource.Resource.set_connection`
-        and the associated `requests.Session` object will also be refreshed.
-
-        Returns:
-            A `requests.Session` object which is used for all API calls.
-        """
-
-        current_session = getattr(self, "_request_session", None)
-        if current_session:
-            conn = self.get_connection()
-            if conn.request_headers and current_session.headers != conn.request_headers:
-                current_session.headers.update(conn.request_headers)
-            return current_session
-
-        conn = self.get_connection()
-
-        self._request_session = requests.Session()
-        self._request_session.mount(
-            '%s://%s' % (conn.scheme, conn.host),
-            requests.adapters.HTTPAdapter(max_retries=5),
-        )
-        if conn.basic_auth:
-            self._request_session.auth = conn.basic_auth
-        else:
-            self._request_session.cert = conn.cert_auth
-        if conn.request_headers:
-            self._request_session.headers.update(conn.request_headers)
-        self._request_session.verify = conn.verify
-        self._request_session.headers.update(
-            {"X-Dot-Client-App": "netapp-ontap-python-%s" % netapp_ontap.__version__}
-        )
-
-        return self._request_session
-
     @classmethod
     def from_dict(cls, input_dict: dict, *args, strict: bool = False) -> "Resource":
         """Construct a resource from a dictionary.
@@ -481,10 +440,10 @@ class Resource:  # pylint: disable=too-many-instance-attributes
 
         host_context = HostConnection.get_host_context()
 
-        if host_context is not None:
-            return host_context
         if self._connection:
             return self._connection
+        if host_context is not None:
+            return host_context
         if config.CONNECTION:
             return config.CONNECTION
 
@@ -506,7 +465,6 @@ class Resource:  # pylint: disable=too-many-instance-attributes
                 to use for all future API calls on this object.
         """
 
-        self._request_session = None
         self._connection = connection
 
     def get_collection_url(self, connection: HostConnection = None) -> str:
@@ -571,12 +529,10 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         url = sample.get_collection_url(connection=connection)
         try:
             while url:
-                response = sample._session.get(  # pylint: disable=protected-access
+                response = sample.get_connection().session.get(  # pylint: disable=protected-access
                     url, params=params
                 )
                 response.raise_for_status()
-                if utils.LOG_ALL_API_CALLS:
-                    utils.pretty_print_request_response(response)
                 body = response.json()
                 next_link = body.get("_links", {}).get("next", {}).get("href", None)
                 if next_link:
@@ -588,8 +544,11 @@ class Resource:  # pylint: disable=too-many-instance-attributes
                     url = ""
 
                 for record in body.get("records", []):
-                    yield cls.from_dict(record, *args)
-        except requests.exceptions.HTTPError as error:
+                    obj = cls.from_dict(record, *args)
+                    if connection is not None:
+                        obj.set_connection(connection)
+                    yield obj
+        except (requests.exceptions.RequestException) as error:
             # our @utils.api wrapper cannot help us generically catch this error
             # since this is a generator function and not a normal function
             utils.on_api_fail(error)
@@ -633,12 +592,12 @@ class Resource:  # pylint: disable=too-many-instance-attributes
 
         # we don't return a NetAppResponse, so handle errors manually
         try:
-            response = sample._session.get(  # pylint: disable=protected-access
+            response = sample.get_connection().session.get(  # pylint: disable=protected-access
                 url, params=kwargs
             )
             response.raise_for_status()
             return response.json().get("num_records", -1)
-        except (requests.exceptions.HTTPError, requests.exceptions.SSLError) as error:
+        except (requests.exceptions.RequestException) as error:
             if config.RAISE_API_ERRORS:
                 raise NetAppRestError(cause=error) from None
             return -1
@@ -679,7 +638,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         params = dict(kwargs)
         url = sample.get_collection_url(connection=connection)
         while url:
-            response = sample._session.patch(  # pylint: disable=protected-access
+            response = sample.get_connection().session.patch(  # pylint: disable=protected-access
                 url,
                 data=json.dumps(body, cls=ResourceJSONEncoder).encode("utf-8"),
                 params=params,
@@ -740,7 +699,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         url = sample.get_collection_url(connection=connection)
         while url:
             body_data = sample._get_body_data(body)  #pylint: disable=protected-access
-            response = sample._session.delete(  # pylint: disable=protected-access
+            response = sample.get_connection().session.delete(  # pylint: disable=protected-access
                 url, json=body_data, params=params,
             )
             response.raise_for_status()
@@ -818,7 +777,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         """
 
         url = "%s%s" % (self.get_connection().origin, self.instance_location)
-        response = self._session.get(url, params=kwargs)
+        response = self.get_connection().session.get(url, params=kwargs)
         response.raise_for_status()
         self._clone_from_dict(response.json())
         self._set_last_state()
@@ -866,7 +825,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         # trim out any keys from the body which are present as part of the path
         for key in self.path_keys:
             body_data.pop(key.split(".")[0], None)
-        response = self._session.post(
+        response = self.get_connection().session.post(
             url,
             data=json.dumps(body_data, cls=ResourceJSONEncoder).encode("utf-8"),
             params=kwargs,
@@ -930,7 +889,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         """
 
         url = "%s%s" % (self.get_connection().origin, self.instance_location)
-        response = self._session.patch(
+        response = self.get_connection().session.patch(
             url,
             data=json.dumps(self._get_changed_data(), cls=ResourceJSONEncoder).encode(
                 "utf-8"
@@ -983,7 +942,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         """
 
         url = "%s%s" % (self.get_connection().origin, self.instance_location)
-        response = self._session.delete(url, json=self._get_body_data(body), params=kwargs)
+        response = self.get_connection().session.delete(url, json=self._get_body_data(body), params=kwargs)
         response.raise_for_status()
         self._last_response = NetAppResponse(response)
 
@@ -1031,7 +990,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         """
 
         url = "%s%s/%s" % (self.get_connection().origin, self.instance_location, path)
-        response = self._session.post(url, json=self._get_body_data(body), params=kwargs)
+        response = self.get_connection().session.post(url, json=self._get_body_data(body), params=kwargs)
         response.raise_for_status()
 
         if poll:
@@ -1147,14 +1106,12 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         """
 
         connection = self._connection
-        session = self._request_session
         parent_keys = self.parent_keys
         self.__dict__ = self.from_dict(  # pylint: disable=attribute-defined-outside-init
             input_dict
         ).__dict__
         self.parent_keys = parent_keys
         self._connection = connection
-        self._request_session = session
 
     def _set_keys(self, post_response: requests.Response) -> None:
         """Parse the Location header from a response and set keys on the object.
@@ -1191,7 +1148,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
             num_tries = 10
             tries = 0
             while tries < num_tries:
-                response = self._session.get(url)
+                response = self.get_connection().session.get(url)
                 if response.json().get("records"):
                     location = response.json()["records"][0]["_links"]["self"]["href"]
                     break
@@ -1345,6 +1302,10 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         request and warn the user that we are doing so
         """
 
+        current_value = schema.fields[field].serialize(field, self)
+        if current_value is None or current_value == missing:
+            return False
+
         action_fields = getattr(schema, "%sable_fields" % action)
         warning = "%s.%s is not a %sable field so it is not being sent."
 
@@ -1356,10 +1317,7 @@ class Resource:  # pylint: disable=too-many-instance-attributes
         elif not field in ref_fields:
             LOGGER.debug(warning, self.__class__.__name__, field, action)
             return True
-
-        current_value = schema.fields[field].serialize(field, self)
-        return current_value is None or current_value == marshmallow.missing
-
+        return False
 
 # pylint: disable=bad-continuation
 def _get_postable_value(
