@@ -134,6 +134,7 @@ URL|Resource
 /api/network/ipspaces| <a title="netapp_ontap.resources.ipspace.Ipspace" href="../resources/ipspace.html"><code>Ipspace</code></a>
 /api/network/http-proxy| <a title="netapp_ontap.resources.network_http_proxy.NetworkHttpProxy" href="../resources/network_http_proxy.html"><code>NetworkHttpProxy</code></a>
 /api/protocols/fpolicy| <a title="netapp_ontap.resources.fpolicy.Fpolicy" href="../resources/fpolicy.html"><code>Fpolicy</code></a>
+/api/security/ipsec| <a title="netapp_ontap.resources.ipsec.Ipsec" href="../resources/ipsec.html"><code>Ipsec</code></a>
 /api/security/roles| <a title="netapp_ontap.resources.role.Role" href="../resources/role.html"><code>Role</code></a>
 /api/support/ems/filters/{ems_filter[name]}/rules| <a title="netapp_ontap.resources.ems_filter_rule.EmsFilterRule" href="../resources/ems_filter_rule.html"><code>EmsFilterRule</code></a>
 /api/storage/flexcache/flexcaches| <a title="netapp_ontap.resources.flexcache.Flexcache" href="../resources/flexcache.html"><code>Flexcache</code></a>
@@ -205,6 +206,7 @@ URL|Resource
 /api/protocols/nvme/services| <a title="netapp_ontap.resources.nvme_service.NvmeService" href="../resources/nvme_service.html"><code>NvmeService</code></a>
 /api/protocols/ndmp/svms| <a title="netapp_ontap.resources.ndmp_svm.NdmpSvm" href="../resources/ndmp_svm.html"><code>NdmpSvm</code></a>
 /api/storage/quota/reports| <a title="netapp_ontap.resources.quota_report.QuotaReport" href="../resources/quota_report.html"><code>QuotaReport</code></a>
+/api/security/ipsec/security-associations| <a title="netapp_ontap.resources.security_association.SecurityAssociation" href="../resources/security_association.html"><code>SecurityAssociation</code></a>
 /api/protocols/san/iscsi/sessions| <a title="netapp_ontap.resources.iscsi_session.IscsiSession" href="../resources/iscsi_session.html"><code>IscsiSession</code></a>
 /api/storage/snaplock/event-retention/policies| <a title="netapp_ontap.resources.snaplock_retention_policy.SnaplockRetentionPolicy" href="../resources/snaplock_retention_policy.html"><code>SnaplockRetentionPolicy</code></a>
 /api/storage/snaplock/file| <a title="netapp_ontap.resources.snaplock_file_retention.SnaplockFileRetention" href="../resources/snaplock_file_retention.html"><code>SnaplockFileRetention</code></a>
@@ -258,6 +260,7 @@ URL|Resource
 /api/protocols/nfs/export-policies/{policy[id]}/rules| <a title="netapp_ontap.resources.export_rule.ExportRule" href="../resources/export_rule.html"><code>ExportRule</code></a>
 /api/security/authentication/cluster/saml-sp| <a title="netapp_ontap.resources.security_saml_sp.SecuritySamlSp" href="../resources/security_saml_sp.html"><code>SecuritySamlSp</code></a>
 /api/storage/aggregates/{aggregate[uuid]}/plexes| <a title="netapp_ontap.resources.plex.Plex" href="../resources/plex.html"><code>Plex</code></a>
+/api/security/ipsec/policies| <a title="netapp_ontap.resources.ipsec_policy.IpsecPolicy" href="../resources/ipsec_policy.html"><code>IpsecPolicy</code></a>
 /api/protocols/cifs/shares/{svm[uuid]}/{cifs_share[share]}/acls| <a title="netapp_ontap.resources.cifs_share_acl.CifsShareAcl" href="../resources/cifs_share_acl.html"><code>CifsShareAcl</code></a>
 /api/security/key-managers/{security_key_manager[uuid]}/key-servers| <a title="netapp_ontap.resources.key_server.KeyServer" href="../resources/key_server.html"><code>KeyServer</code></a>
 /api/application/applications/{application[uuid]}/snapshots| <a title="netapp_ontap.resources.application_snapshot.ApplicationSnapshot" href="../resources/application_snapshot.html"><code>ApplicationSnapshot</code></a>
@@ -297,6 +300,7 @@ from netapp_ontap.resources.snaplock_file_fingerprint import SnaplockFileFingerp
 from netapp_ontap.resources.ipspace import Ipspace
 from netapp_ontap.resources.network_http_proxy import NetworkHttpProxy
 from netapp_ontap.resources.fpolicy import Fpolicy
+from netapp_ontap.resources.ipsec import Ipsec
 from netapp_ontap.resources.role import Role
 from netapp_ontap.resources.ems_filter_rule import EmsFilterRule
 from netapp_ontap.resources.flexcache import Flexcache
@@ -368,6 +372,7 @@ from netapp_ontap.resources.cluster import Cluster
 from netapp_ontap.resources.nvme_service import NvmeService
 from netapp_ontap.resources.ndmp_svm import NdmpSvm
 from netapp_ontap.resources.quota_report import QuotaReport
+from netapp_ontap.resources.security_association import SecurityAssociation
 from netapp_ontap.resources.iscsi_session import IscsiSession
 from netapp_ontap.resources.snaplock_retention_policy import SnaplockRetentionPolicy
 from netapp_ontap.resources.snaplock_file_retention import SnaplockFileRetention
@@ -421,6 +426,7 @@ from netapp_ontap.resources.configuration_backup import ConfigurationBackup
 from netapp_ontap.resources.export_rule import ExportRule
 from netapp_ontap.resources.security_saml_sp import SecuritySamlSp
 from netapp_ontap.resources.plex import Plex
+from netapp_ontap.resources.ipsec_policy import IpsecPolicy
 from netapp_ontap.resources.cifs_share_acl import CifsShareAcl
 from netapp_ontap.resources.key_server import KeyServer
 from netapp_ontap.resources.application_snapshot import ApplicationSnapshot
@@ -453,6 +459,7 @@ __all__ = [
     "Ipspace",
     "NetworkHttpProxy",
     "Fpolicy",
+    "Ipsec",
     "Role",
     "EmsFilterRule",
     "Flexcache",
@@ -524,6 +531,7 @@ __all__ = [
     "NvmeService",
     "NdmpSvm",
     "QuotaReport",
+    "SecurityAssociation",
     "IscsiSession",
     "SnaplockRetentionPolicy",
     "SnaplockFileRetention",
@@ -577,6 +585,7 @@ __all__ = [
     "ExportRule",
     "SecuritySamlSp",
     "Plex",
+    "IpsecPolicy",
     "CifsShareAcl",
     "KeyServer",
     "ApplicationSnapshot",
