@@ -55,16 +55,17 @@ class CloudTargetSchema(ResourceSchema):
 
     authentication_type = fields.Str(
         data_key="authentication_type",
-        validate=enum_validation(['key', 'cap', 'ec2_iam', 'gcp_sa']),
+        validate=enum_validation(['key', 'cap', 'ec2_iam', 'gcp_sa', 'azure_msi']),
     )
-    r""" Authentication used to access the target. Snapmirror does not yet support CAP. Required in POST.
+    r""" Authentication used to access the target. SnapMirror does not yet support CAP. Required in POST.
 
 Valid choices:
 
 * key
 * cap
 * ec2_iam
-* gcp_sa """
+* gcp_sa
+* azure_msi """
 
     azure_account = fields.Str(
         data_key="azure_account",
@@ -167,6 +168,17 @@ Valid choices:
     svm = fields.Nested("netapp_ontap.resources.svm.SvmSchema", data_key="svm", unknown=EXCLUDE)
     r""" The svm field of the cloud_target. """
 
+    url_style = fields.Str(
+        data_key="url_style",
+        validate=enum_validation(['path_style', 'virtual_hosted_style']),
+    )
+    r""" URL style used to access S3 bucket.
+
+Valid choices:
+
+* path_style
+* virtual_hosted_style """
+
     use_http_proxy = fields.Boolean(
         data_key="use_http_proxy",
     )
@@ -205,6 +217,7 @@ Valid choices:
             "ssl_enabled",
             "svm.name",
             "svm.uuid",
+            "url_style",
             "use_http_proxy",
         ]
 
@@ -232,6 +245,7 @@ Valid choices:
             "ssl_enabled",
             "svm.name",
             "svm.uuid",
+            "url_style",
             "use_http_proxy",
         ]
 
@@ -373,7 +387,7 @@ class CloudTarget(Resource):
 * `svm.name` or `svm.uuid` - Name or UUID of SVM if `owner` is _snapmirror_.
 * `snapmirror_use` - Use of the cloud target if `owner` is _snapmirror_: data, metadata.
 ### Recommended optional properties
-* `authentication_type` - Authentication used to access the target: _key_, _cap_, _ec2_iam_, _gcp_sa_.
+* `authentication_type` - Authentication used to access the target: _key_, _cap_, _ec2_iam_, _gcp_sa_, _azure_msi_.
 * `ssl_enabled` - SSL/HTTPS enabled or disabled.
 * `port` - Port number of the object store that ONTAP uses when establishing a connection.
 * `ipspace` - IPspace to use in order to reach the cloud target.
@@ -382,6 +396,7 @@ class CloudTarget(Resource):
 * `authentication_type`
   - _ec2_iam_ - if running in Cloud Volumes ONTAP in AWS
   - _gcp_sa_ - if running in Cloud Volumes ONTAP in GCP
+  - _azure_msi_ - if running in Cloud Volumes ONTAP in Azure
   - _key_  - in all other cases.
 * `server`
   - _s3.amazonaws.com_ - if `provider_type` is _AWS_S3_
@@ -401,6 +416,9 @@ class CloudTarget(Resource):
 * `server_side_encryption`
   - _none_ - if `provider_type` is _ONTAP_S3_
   - _sse_s3_ - if `provider_type` is not _ONTAP_S3_
+* `url_style`
+  - _path_style_ - if `provider_type` is neither _AWS_S3_ nor _AliCloud_
+  - _virtual_hosted_style_ - if `provider_type` is either _AWS_S3 or _AliCloud__
 ### Related ONTAP commands
 * `storage aggregate object-store config create`
 
